@@ -875,9 +875,9 @@ class WaldurClient(object):
     ):
         url = self._build_resource_url(
             self.Endpoints.MarketplacePublicOffering,
-            "plans",
             offering_uuid,
-            plan_uuid,
+            sub_endpoint="plans",
+            uid2=plan_uuid,
         )
         return self._get(url, valid_states=[200])
 
@@ -1671,9 +1671,9 @@ class WaldurClient(object):
         if plan_uuid:
             order_item["plan"] = self._build_resource_url(
                 self.Endpoints.MarketplacePublicOffering,
-                "plans",
                 offering_uuid,
-                plan_uuid,
+                sub_endpoint="plans",
+                uid2=plan_uuid,
             )
 
         if callback_url:
